@@ -1,14 +1,14 @@
 package Net::OAuth;
 use warnings;
 use strict;
-use UNIVERSAL::require;
+use Carp;
 
 sub PROTOCOL_VERSION_1_0() {1}
 sub PROTOCOL_VERSION_1_0A() {1.001}
 
 sub OAUTH_VERSION() {'1.0'}
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 our $SKIP_UTF8_DOUBLE_ENCODE_CHECK = 0; # this is not actually used any more
 our $PROTOCOL_VERSION = PROTOCOL_VERSION_1_0;
 
@@ -29,7 +29,7 @@ sub message {
     my $base_class = ref $self || $self;
     my $type = camel(shift);
     my $class = $base_class . '::' . $type;
-    smart_require($class);
+    smart_require($class, 1);
     return $class;
 }
 
@@ -48,8 +48,10 @@ our %ALREADY_REQUIRED = (); # class_name => rv of ->require
 
 sub smart_require {
     my $required_class = shift;
+    my $croak_on_error = shift || 0;
     unless (exists $ALREADY_REQUIRED{$required_class}) {
-        $ALREADY_REQUIRED{$required_class} = $required_class->require;
+        $ALREADY_REQUIRED{$required_class} = eval "require $required_class";
+        croak $@ if $@ and $croak_on_error;
     }
     return $ALREADY_REQUIRED{$required_class};
 }
